==> codeocean_mcp_server-0.1.0.tar.gz: codeocean_mcp_server-0.1.0/src/codeocean_mcp_server/tools/capsules.py <==
from codeocean import CodeOcean
from codeocean.capsule import (
    Capsule,
    CapsuleSearchParams,
    CapsuleSearchResults,
    Computation,
    DataAssetAttachParams,
    DataAssetAttachResults,
)
from mcp.server.fastmcp import FastMCP

from codeocean_mcp_server.models import dataclass_to_pydantic

CapsuleModel = dataclass_to_pydantic(Capsule)
CapsuleSearchParamsModel = dataclass_to_pydantic(CapsuleSearchParams)
CapsuleSearchResultsModel = dataclass_to_pydantic(CapsuleSearchResults)
ComputationModel = dataclass_to_pydantic(Computation)
DataAssetAttachParamsModel = dataclass_to_pydantic(DataAssetAttachParams)
DataAssetAttachResultsModel = dataclass_to_pydantic(DataAssetAttachResults)


def add_tools(mcp: FastMCP, client: CodeOcean):
    """Add capsule tools to the MCP server."""

    @mcp.tool(
        description=(
            str(client.capsules.search_capsules.__doc__)
            + "Use only for capsule searches. "
            "Provide only the minimal required parameters (e.g. limit=10); "
            "do not include optional params "
            "like sort_by or sort_order unless requested."
        )
    )
    def search_capsules(
        search_params: CapsuleSearchParamsModel,
    ) -> CapsuleSearchResultsModel:
        """Search for capsules matching specified criteria."""
        params = CapsuleSearchParams(**search_params.model_dump(exclude_none=True))
        return dataclass_to_pydantic(client.capsules.search_capsules(params))

    @mcp.tool(
        description=(
            str(client.capsules.attach_data_assets.__doc__)
            + "Accepts a list of parameter objects (e.g. [{'id': '...'}]), "
            "not just a list of IDs."
        )
    )
    def attach_data_assets(
        capsule_id: str,
        data_asset_ids: list[DataAssetAttachParamsModel],
    ) -> list[DataAssetAttachResultsModel]:
        """Attach data assets to a capsule."""
        return [
            dataclass_to_pydantic(result)
            for result in client.capsules.attach_data_assets(capsule_id, data_asset_ids)
        ]

    @mcp.tool(
        description=(
            str(client.capsules.get_capsule.__doc__)
            + "Use only to fetch metadata for a known capsule ID. "
            "Do not use for searching."
        )
    )
    def get_capsule(capsule_id: str) -> CapsuleModel:
        """Retrieve a capsule by its ID."""
        return dataclass_to_pydantic(client.capsules.get_capsule(capsule_id))

    @mcp.tool(description=client.capsules.list_computations.__doc__)
    def list_computations(capsule_id: str) -> list[ComputationModel]:
        """List all computations for a capsule."""
        return [
            dataclass_to_pydantic(computation)
            for computation in client.capsules.list_computations(capsule_id)
        ]

==> codeocean_mcp_server-0.2.0.tar.gz: codeocean_mcp_server-0.2.0/src/codeocean_mcp_server/tools/capsules.py <==
from codeocean import CodeOcean
from codeocean.capsule import (
    Capsule,
    CapsuleSearchParams,
    CapsuleSearchResults,
    Computation,
    DataAssetAttachParams,
    DataAssetAttachResults,
)
from mcp.server.fastmcp import FastMCP

from codeocean_mcp_server.models import dataclass_to_pydantic

CapsuleSearchParamsModel = dataclass_to_pydantic(CapsuleSearchParams)
DataAssetAttachParamsModel = dataclass_to_pydantic(DataAssetAttachParams)


def add_tools(mcp: FastMCP, client: CodeOcean):
    """Add capsule tools to the MCP server."""

    @mcp.tool(
        description=(
            str(client.capsules.search_capsules.__doc__)
            + "Use only for capsule searches. "
            "Provide only the minimal required parameters (e.g. limit=10); "
            "do not include optional params "
            "like sort_by or sort_order unless requested."
        )
    )
    def search_capsules(search_params: CapsuleSearchParamsModel) -> CapsuleSearchResults:
        """Search for capsules matching specified criteria."""
        params = CapsuleSearchParams(**search_params.model_dump(exclude_none=True))
        return client.capsules.search_capsules(params)

    @mcp.tool(
        description=(
            str(client.capsules.attach_data_assets.__doc__)
            + "Accepts a list of parameter objects (e.g. [{'id': '...'}]), "
            "not just a list of IDs."
        )
    )
    def attach_data_assets(
        capsule_id: str,
        attach_params: list[DataAssetAttachParamsModel],
    ) -> list[DataAssetAttachResults]:
        """Attach data assets to a capsule."""
        params = [
            DataAssetAttachParams(**p.model_dump(exclude_none=True))
            for p in attach_params
        ]
        return client.capsules.attach_data_assets(capsule_id, params)

    @mcp.tool(
        description=(
            str(client.capsules.get_capsule.__doc__)
            + "Use only to fetch metadata for a known capsule ID. "
            "Do not use for searching."
        )
    )
    def get_capsule(capsule_id: str) -> Capsule:
        """Retrieve a capsule by its ID."""
        return client.capsules.get_capsule(capsule_id)

    @mcp.tool(description=client.capsules.list_computations.__doc__)
    def list_computations(capsule_id: str) -> list[Computation]:
        """List all computations for a capsule."""
        return client.capsules.list_computations(capsule_id)
